// Generated by gmmproc 2.63.1 -- DO NOT MODIFY!
#ifndef _GIOMM_SETTINGSSCHEMAKEY_P_H
#define _GIOMM_SETTINGSSCHEMAKEY_P_H


#include <glibmm/private/object_p.h>


#endif /* _GIOMM_SETTINGSSCHEMAKEY_P_H */

